@@ -26,11 +26,22 @@ datatypes = {XSD.string: 'STRING',
              XSD.decimal: 'FLOAT',
              XSD.double: 'FLOAT'}
 
+def chop(uriref):
+    if '#' in uriref:
+        return uriref.toPython().split("#")[-1]
+    elif '/' in uriref:
+        return uriref.toPython().split("/")[-1]
+    else:
+        return uriref
+
 def get_label(uri, graph):
     label = None
     name = graph.objects(uri, RDFS.label)
-    for n in name:
-            label = n    
+    if name is None:
+        label = chop(uri)
+    else:
+        for n in name:
+                label = n    
     return label
 
 class owlobject:
@@ -287,8 +298,12 @@ class owlinstance(owlobject):
                 curi = c
 
         iclass_name = graph.objects(curi, RDFS.label)
+
+
         for n in iclass_name:
             self.iclass_label = n.replace(' ', '_') 
+        if self.iclass_label is None:
+            self.iclass_label = self.chop(curi)
 
         # If individual has no class something is wrong
         if self.iclass is None:
@@ -306,6 +321,8 @@ class owlinstance(owlobject):
                 val = [v for v in graph.objects(self.uriref, prop.uriref)]
                 if len(val) > 0:
                     label = get_label(prop.uriref, graph)
+                    if label is None:
+                        label = self.chop(prop.uriref)
                     self.properties[prop.name] = (val, prop.attributes[RDFS.range], label.replace(' ', '_'))
 
     def toCLIPS(self, graph, labels=False):
